## SupplyNetPy `Components.utilities` Module

The utility module offers various functions to create, simulate, access information, and visualize the supply chain network more effectively.

<div id="create_sc_net"></div>

## Creating a Supply Chain Network 

::: SupplyNetPy.Components.utilities
    options:
      members:
        - create_sc_net

---

<div id="check_duplicate_id"></div>
The following is a helper function used by `create_sc_net()` to check if there are duplicate IDs.

::: SupplyNetPy.Components.utilities
    options:
      members:
        - check_duplicate_id

---

<div id="simulate_sc_net"></div>

## Simulating the Network

::: SupplyNetPy.Components.utilities
    options:
      members:
        - simulate_sc_net
---

<div id="visualize_sc_net"></div>

## Visualizing the Network

::: SupplyNetPy.Components.utilities
    options:
      members:
        - visualize_sc_net
---

<div id="print_node_wise_performance"></div>

## Printing Node-wise Performance

::: SupplyNetPy.Components.utilities
    options:
      members:
        - print_node_wise_performance
---

<div id="get_sc_net_info"></div>

## Getting Supply Chain Information

::: SupplyNetPy.Components.utilities
    options:
      members:
        - get_sc_net_info

---

<div id="process_info_dict"></div>

The following is a helper function that gets information from individual nodes or links used in `get_sc_net_info()`.

::: SupplyNetPy.Components.utilities
    options:
      members:
        - process_info_dict
